summaryrefslogtreecommitdiff
path: root/common
diff options
context:
space:
mode:
authorShane Kerr <shane@isc.org>2007-01-29 10:25:55 +0000
committerShane Kerr <shane@isc.org>2007-01-29 10:25:55 +0000
commitc57db45ce9001226f23d1371199f616d60181c76 (patch)
treec3b24f24767016e64b2314bb3ee4ad26d90782ea /common
parent253c8b6ad1f0696cf631331e2ce3a6da341c240e (diff)
downloadisc-dhcp-c57db45ce9001226f23d1371199f616d60181c76.tar.gz
Spelling fixes. See RT ticket 16513 for details.
Diffstat (limited to 'common')
-rw-r--r--common/options.c4
-rw-r--r--common/parse.c38
-rw-r--r--common/print.c4
-rw-r--r--common/tables.c8
-rw-r--r--common/tree.c14
5 files changed, 34 insertions, 34 deletions
diff --git a/common/options.c b/common/options.c
index 68812e1b..4b7aa35f 100644
--- a/common/options.c
+++ b/common/options.c
@@ -34,7 +34,7 @@
#ifndef lint
static char copyright[] =
-"$Id: options.c,v 1.102 2007/01/11 16:31:51 dhankins Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
+"$Id: options.c,v 1.103 2007/01/29 10:25:54 shane Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
#endif /* not lint */
#define DHCP_OPTION_DATA
@@ -476,7 +476,7 @@ int fqdn_universe_decode (struct option_state *options,
}
/* cons options into a big buffer, and then split them out into the
- three seperate buffers if needed. This allows us to cons up a set
+ three separate buffers if needed. This allows us to cons up a set
of vendor options using the same routine. */
int cons_options (inpacket, outpacket, lease, client_state,
diff --git a/common/print.c b/common/print.c
index f068ecdf..f8251777 100644
--- a/common/print.c
+++ b/common/print.c
@@ -34,7 +34,7 @@
#ifndef lint
static char copyright[] =
-"$Id: print.c,v 1.62 2007/01/28 23:00:19 each Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
+"$Id: print.c,v 1.63 2007/01/29 10:25:54 shane Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
#endif /* not lint */
#include "dhcpd.h"
@@ -918,7 +918,7 @@ static unsigned print_subexpression (expr, buf, len)
rv += print_subexpression (expr -> data.b2a.width,
buf + rv, len - rv - 3);
buf [rv++] = ' ';
- rv += print_subexpression (expr -> data.b2a.seperator,
+ rv += print_subexpression (expr -> data.b2a.separator,
buf + rv, len - rv - 2);
buf [rv++] = ' ';
rv += print_subexpression (expr -> data.b2a.buffer,
diff --git a/common/tables.c b/common/tables.c
index b4b47ba6..9740257c 100644
--- a/common/tables.c
+++ b/common/tables.c
@@ -34,7 +34,7 @@
#ifndef lint
static char copyright[] =
-"$Id: tables.c,v 1.60 2006/10/27 22:54:12 dhankins Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
+"$Id: tables.c,v 1.61 2007/01/29 10:25:54 shane Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
#endif /* not lint */
#include "dhcpd.h"
@@ -74,7 +74,7 @@ HASH_FUNCTIONS (option_code, const unsigned *, struct option,
F - implicit flag - the presence of the option indicates that the
flag is true.
o - the preceding value is optional.
- E - encapsulation, string or colon-seperated hex list (the latter
+ E - encapsulation, string or colon-separated hex list (the latter
two for parsing). E is followed by a text string containing
the name of the option space to encapsulate, followed by a '.'.
If the E is immediately followed by '.', the applicable vendor
@@ -86,9 +86,9 @@ HASH_FUNCTIONS (option_code, const unsigned *, struct option,
thing in the option.
X - either an ASCII string or binary data. On output, the string is
scanned to see if it's printable ASCII and, if so, output as a
- quoted string. If not, it's output as colon-seperated hex. On
+ quoted string. If not, it's output as colon-separated hex. On
input, the option can be specified either as a quoted string or as
- a colon-seperated hex list.
+ a colon-separated hex list.
N - enumeration. N is followed by a text string containing
the name of the set of enumeration values to parse or emit,
followed by a '.'. The width of the data is specified in the
diff --git a/common/parse.c b/common/parse.c
index 486d0cd2..8c0be7ad 100644
--- a/common/parse.c
+++ b/common/parse.c
@@ -34,7 +34,7 @@
#ifndef lint
static char copyright[] =
-"$Id: parse.c,v 1.118 2007/01/28 23:00:19 each Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
+"$Id: parse.c,v 1.119 2007/01/29 10:25:54 shane Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
#endif /* not lint */
#include "dhcpd.h"
@@ -414,7 +414,7 @@ parse_ip_addr_with_subnet(cfile, match)
}
/*
- * hardware-parameter :== HARDWARE hardware-type colon-seperated-hex-list SEMI
+ * hardware-parameter :== HARDWARE hardware-type colon-separated-hex-list SEMI
* hardware-type :== ETHERNET | TOKEN_RING | FDDI
*/
@@ -513,18 +513,18 @@ void parse_lease_time (cfile, timep)
}
/* No BNF for numeric aggregates - that's defined by the caller. What
- this function does is to parse a sequence of numbers seperated by
- the token specified in seperator. If max is zero, any number of
+ this function does is to parse a sequence of numbers separated by
+ the token specified in separator. If max is zero, any number of
numbers will be parsed; otherwise, exactly max numbers are
expected. Base and size tell us how to internalize the numbers
once they've been tokenized. */
unsigned char *parse_numeric_aggregate (cfile, buf,
- max, seperator, base, size)
+ max, separator, base, size)
struct parse *cfile;
unsigned char *buf;
unsigned *max;
- int seperator;
+ int separator;
int base;
unsigned size;
{
@@ -545,7 +545,7 @@ unsigned char *parse_numeric_aggregate (cfile, buf,
do {
if (count) {
token = peek_token (&val, (unsigned *)0, cfile);
- if (token != seperator) {
+ if (token != separator) {
if (!*max)
break;
if (token != RBRACE && token != LBRACE)
@@ -802,11 +802,11 @@ TIME parse_date (cfile)
if (year > 1900)
year -= 1900;
/* Slash seperating year from month... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != SLASH) {
parse_warn (cfile,
- "expected slash seperating year from month.");
+ "expected slash separating year from month.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -822,11 +822,11 @@ TIME parse_date (cfile)
}
mon = atoi (val) - 1;
/* Slash seperating month from day... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != SLASH) {
parse_warn (cfile,
- "expected slash seperating month from day.");
+ "expected slash separating month from day.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -852,11 +852,11 @@ TIME parse_date (cfile)
}
hour = atoi (val);
/* Colon seperating hour from minute... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != COLON) {
parse_warn (cfile,
- "expected colon seperating hour from minute.");
+ "expected colon separating hour from minute.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -872,11 +872,11 @@ TIME parse_date (cfile)
}
min = atoi (val);
/* Colon seperating minute from second... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != COLON) {
parse_warn (cfile,
- "expected colon seperating hour from minute.");
+ "expected colon separating hour from minute.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -1701,8 +1701,8 @@ int parse_base64 (data, cfile)
/*
- * colon-seperated-hex-list :== NUMBER |
- * NUMBER COLON colon-seperated-hex-list
+ * colon-separated-hex-list :== NUMBER |
+ * NUMBER COLON colon-separated-hex-list
*/
int parse_cshl (data, cfile)
@@ -3101,7 +3101,7 @@ int parse_boolean_expression (expr, cfile, lose)
* PACKET LPAREN numeric-expression COMMA
* numeric-expression RPAREN |
* STRING |
- * colon_seperated_hex_list
+ * colon_separated_hex_list
*/
int parse_data_expression (expr, cfile, lose)
@@ -3519,7 +3519,7 @@ int parse_non_binary (expr, cfile, lose, context)
if (token != COMMA)
goto nocomma;
- if (!parse_data_expression (&(*expr) -> data.b2a.seperator,
+ if (!parse_data_expression (&(*expr) -> data.b2a.separator,
cfile, lose))
goto nodata;
@@ -802,11 +802,11 @@ TIME parse_date (cfile)
if (year > 1900)
year -= 1900;
- /* Slash seperating year from month... */
+ /* Slash separating year from month... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != SLASH) {
@@ -822,11 +822,11 @@ TIME parse_date (cfile)
}
mon = atoi (val) - 1;
- /* Slash seperating month from day... */
+ /* Slash separating month from day... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != SLASH) {
@@ -852,11 +852,11 @@ TIME parse_date (cfile)
}
hour = atoi (val);
- /* Colon seperating hour from minute... */
+ /* Colon separating hour from minute... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != COLON) {
@@ -872,11 +872,11 @@ TIME parse_date (cfile)
}
min = atoi (val);
- /* Colon seperating minute from second... */
+ /* Colon separating minute from second... */
token = next_token (&val, (unsigned *)0, cfile);
if (token != COLON) {
diff --git a/common/tree.c b/common/tree.c
index f3d8d3e3..8f2b7879 100644
--- a/common/tree.c
+++ b/common/tree.c
@@ -34,7 +34,7 @@
#ifndef lint
static char copyright[] =
-"$Id: tree.c,v 1.111 2007/01/28 23:00:19 each Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
+"$Id: tree.c,v 1.112 2007/01/29 10:25:54 shane Exp $ Copyright (c) 2004-2006 Internet Systems Consortium. All rights reserved.\n";
#endif /* not lint */
#include "dhcpd.h"
@@ -852,7 +852,7 @@ int evaluate_dns_expression (result, packet, lease, client_state, in_options,
ASCII string both look like data expressions, but
for A records, we want an ASCII string, not a
binary IP address. Do I need to turn binary IP
- addresses into a seperate type? */
+ addresses into a separate type? */
return (r0 && r1 &&
(r2 || expr -> op != expr_ns_add) && *result);
@@ -1825,12 +1825,12 @@ int evaluate_data_expression (result, packet, lease, client_state,
scope,
expr -> data.b2a.width);
/* Evaluate the seperator string. */
memset (&data, 0, sizeof data);
s2 = evaluate_data_expression (&data, packet, lease,
client_state,
in_options, cfg_options, scope,
- expr -> data.b2a.seperator,
+ expr -> data.b2a.separator,
MDL);
/* Evaluate the data to be converted. */
@@ -2997,8 +2997,8 @@ void expression_dereference (eptr, file, line)
if (expr -> data.b2a.width)
expression_dereference (&expr -> data.b2a.width,
file, line);
- if (expr -> data.b2a.seperator)
- expression_dereference (&expr -> data.b2a.seperator,
+ if (expr -> data.b2a.separator)
+ expression_dereference (&expr -> data.b2a.separator,
file, line);
if (expr -> data.b2a.buffer)
expression_dereference (&expr -> data.b2a.buffer,
@@ -3693,7 +3693,7 @@ int write_expression (file, expr, col, indent, firstp)
col, scol, 0);
col = token_print_indent (file, col, scol, "", " ",
",");
- col = write_expression (file, expr -> data.b2a.seperator,
+ col = write_expression (file, expr -> data.b2a.separator,
col, scol, 0);
col = token_print_indent (file, col, scol, "", " ",
",");
@@ -1825,12 +1825,12 @@ int evaluate_data_expression (result, packet, lease, client_state,
scope,
expr -> data.b2a.width);
- /* Evaluate the seperator string. */
+ /* Evaluate the separator string. */
memset (&data, 0, sizeof data);
s2 = evaluate_data_expression (&data, packet, lease,